@@ -279,7 +279,7 @@ bool luks::cryptOpen(QWidget* parent, const QString& deviceNode)
     if (!m_isCryptOpen)
         return false;
 
-    for (auto &p : LVM::pvList) // FIXME: qAsConst
+    for (auto &p : LVM::pvList)
         if (p.isLuks() && p.partition()->deviceNode() == deviceNode && p.partition()->fileSystem().type() == FileSystem::Lvm2_PV)
             p.setLuks(false);
 
@@ -318,7 +318,7 @@ bool luks::cryptClose(const QString& deviceNode)
 
     m_isCryptOpen = (m_innerFs != nullptr);
 
-    for (auto &p : LVM::pvList) // FIXME: qAsConst
+    for (auto &p : LVM::pvList)
         if (!p.isLuks() && p.partition()->deviceNode() == deviceNode)
             p.setLuks(true);
 
