@@ -22,7 +22,7 @@
 #include "plugins/dummy/dummybackend.h"
 #include "plugins/dummy/dummydevice.h"
 
-#include "core/device.h"
+#include "core/diskdevice.h"
 #include "core/partition.h"
 #include "core/partitiontable.h"
 
@@ -46,9 +46,9 @@ void DummyBackend::initFSSupport()
 {
 }
 
-QList<Device*> DummyBackend::scanDevices(bool excludeReadOnly)
+QList<Device*> DummyBackend::scanDevices(bool excludeLoop)
 {
-    Q_UNUSED(excludeReadOnly)
+    Q_UNUSED(excludeLoop)
     QList<Device*> result;
     result.append(scanDevice(QStringLiteral("/dev/sda")));
 
@@ -59,7 +59,7 @@ QList<Device*> DummyBackend::scanDevices(bool excludeReadOnly)
 
 Device* DummyBackend::scanDevice(const QString& device_node)
 {
-    Device* d = new Device(QStringLiteral("Dummy Device"), QStringLiteral("/tmp") + device_node, 255, 30, 63, 512);
+    DiskDevice* d = new DiskDevice(QStringLiteral("Dummy Device"), QStringLiteral("/tmp") + device_node, 255, 30, 63, 512);
     CoreBackend::setPartitionTableForDevice(*d, new PartitionTable(PartitionTable::msdos_sectorbased, 2048, d->totalSectors() - 2048));
     CoreBackend::setPartitionTableMaxPrimaries(*d->partitionTable(), 128);
     d->partitionTable()->updateUnallocated(*d);
