@@ -374,7 +374,7 @@ void LibPartedBackend::scanDevicePartitions(Device& d, PedDisk* pedDisk)
     if (d.partitionTable()->isSectorBased(d))
         d.partitionTable()->setType(d, PartitionTable::msdos_sectorbased);
 
-    foreach(const Partition * part, partitions)
+    for (const Partition * part : qAsConst(partitions))
         PartitionAlignment::isAligned(d, *part);
 }
 
@@ -419,6 +419,7 @@ QList<Device*> LibPartedBackend::scanDevices(bool excludeReadOnly)
         "8,65,66,67,68,69,70,71," // SCSI disk devices
         "80,81,82,83,84,85,86,87," // I2O hard disk
         "179," // MMC block devices
+        "253," // Virtio KVM devices (e.g. /dev/vda)
         "259" // Block Extended Major (include NVMe)
     );
     ExternalCommand cmd(QStringLiteral("lsblk"), {
@@ -440,7 +441,10 @@ QList<Device*> LibPartedBackend::scanDevices(bool excludeReadOnly)
             }
 
             emitScanProgress(devices[i], i * 100 / totalDevices);
-            result.append(scanDevice(devices[i]));
+            Device* device = scanDevice(devices[i]);
+            if(device != nullptr) {
+                result.append(device);
+            }
         }
     }
 
