@@ -20,8 +20,6 @@
 
 #include "util/report.h"
 
-#include <cstdlib>
-
 #include <QString>
 #include <QStringList>
 
@@ -60,8 +58,8 @@ ExternalCommand::ExternalCommand(Report& report, const QString& cmd, const QStri
 
 void ExternalCommand::setup()
 {
-    setEnvironment(QStringList() << QStringLiteral("LC_ALL=C") << QStringLiteral("PATH=") + QString::fromUtf8(getenv("PATH")));
-    setProcessChannelMode(MergedChannels);
+    setEnvironment(QStringList() << QStringLiteral("LC_ALL=C") << QStringLiteral("PATH=") + QString::fromUtf8(getenv("PATH")) << QStringLiteral("LVM_SUPPRESS_FD_WARNINGS=1"));
+    setProcessChannelMode(SeparateChannels);
 
     connect(this, static_cast<void(QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished), this, &ExternalCommand::onFinished);
     connect(this, &ExternalCommand::readyReadStandardOutput, this, &ExternalCommand::onReadOutput);
@@ -76,13 +74,13 @@ bool ExternalCommand::start(int timeout)
     QProcess::start(command(), args());
 
     if (report()) {
-        report()->setCommand(i18nc("@info/plain", "Command: %1 %2", command(), args().join(QStringLiteral(" "))));
+        report()->setCommand(xi18nc("@info:status", "Command: %1 %2", command(), args().join(QStringLiteral(" "))));
     }
 
     if (!waitForStarted(timeout))
     {
         if (report())
-            report()->line() << i18nc("@info/plain", "(Command timeout while starting)");
+            report()->line() << xi18nc("@info:status", "(Command timeout while starting)");
         return false;
     }
 
@@ -99,7 +97,7 @@ bool ExternalCommand::waitFor(int timeout)
 
     if (!waitForFinished(timeout)) {
         if (report())
-            report()->line() << i18nc("@info/plain", "(Command timeout while running)");
+            report()->line() << xi18nc("@info:status", "(Command timeout while running)");
         return false;
     }
 
